import tkinter as tk
from tkinter import ttk, messagebox
import json
import os

# JSON file to store user data
FILE_PATH = "users.json"

# Load users from JSON file
def load_users():
    if not os.path.exists(FILE_PATH):
        return []
    with open(FILE_PATH, "r") as file:
        return json.load(file)

# Save users to JSON file
def save_users(users):
    with open(FILE_PATH, "w") as file:
        json.dump(users, file, indent=4)

# Check if user exists
def user_exists(username):
    users = load_users()
    return any(user["username"] == username for user in users)

# Main App Class
class App(tk.Tk):
    def __init__(self):
        super().__init__()
        self.geometry("300x150")
        self.title('Login')
        self.resizable(False, False)
        self.configure(bg="blue")
        self.create_widgets()

    def create_widgets(self):
        self.username = tk.StringVar()
        self.password = tk.StringVar()

        ttk.Label(self, text="Username:").grid(column=0, row=0, padx=5, pady=5, sticky=tk.W)
        ttk.Entry(self, textvariable=self.username).grid(column=1, row=0, padx=5, pady=5)
        
        ttk.Label(self, text="Password:").grid(column=0, row=1, padx=5, pady=5, sticky=tk.W)
        ttk.Entry(self, textvariable=self.password, show="*").grid(column=1, row=1, padx=5, pady=5)

        ttk.Button(self, text="Login", command=self.login).grid(column=0, row=2, padx=5, pady=5)
        ttk.Button(self, text="Register", command=self.open_register_window).grid(column=1, row=2, padx=5, pady=5)

    def login(self):
        username = self.username.get()
        password = self.password.get()
        users = load_users()

        for user in users:
            if user["username"] == username and user["password"] == password:
                messagebox.showinfo("Success", "Login successful!")
                return

        messagebox.showerror("Error", "Invalid username or password! Please register.")

    def open_register_window(self):
        RegisterWindow(self)

# Registration Window
class RegisterWindow(tk.Toplevel):
    def __init__(self, parent):
        super().__init__(parent)
        self.geometry("300x200")
        self.title("Register")
        self.resizable(False, False)

        self.new_username = tk.StringVar()
        self.new_password = tk.StringVar()
        self.email = tk.StringVar()
        self.full_name = tk.StringVar()

        ttk.Label(self, text="Full Name:").grid(column=0, row=0, padx=5, pady=5, sticky=tk.W)
        ttk.Entry(self, textvariable=self.full_name).grid(column=1, row=0, padx=5, pady=5)
        
        ttk.Label(self, text="Email:").grid(column=0, row=1, padx=5, pady=5, sticky=tk.W)
        ttk.Entry(self, textvariable=self.email).grid(column=1, row=1, padx=5, pady=5)
        
        ttk.Label(self, text="Username:").grid(column=0, row=2, padx=5, pady=5, sticky=tk.W)
        ttk.Entry(self, textvariable=self.new_username).grid(column=1, row=2, padx=5, pady=5)
        
        ttk.Label(self, text="Password:").grid(column=0, row=3, padx=5, pady=5, sticky=tk.W)
        ttk.Entry(self, textvariable=self.new_password, show="*").grid(column=1, row=3, padx=5, pady=5)

        ttk.Button(self, text="OK", command=self.register_user).grid(column=0, row=4, padx=5, pady=5)
        ttk.Button(self, text="Cancel", command=self.destroy).grid(column=1, row=4, padx=5, pady=5)

    def register_user(self):
        new_user = self.new_username.get()
        new_pass = self.new_password.get()
        email = self.email.get()
        full_name = self.full_name.get()
        
        if user_exists(new_user):
            messagebox.showerror("Error", "User already exists!")
            return

        users = load_users()
        users.append({"username": new_user, "password": new_pass, "email": email, "full_name": full_name})
        save_users(users)

        messagebox.showinfo("Success", "Registration successful!")
        self.destroy()

if __name__ == "__main__":
    app = App()
    app.mainloop()
